@@ -6,7 +6,7 @@ use Authen::Simple::Password;
 use Authen::Simple::Passwd;
 use Authen::Simple::LDAP;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub register {
     my ( $plugin, $app ) = @_;
@@ -116,7 +116,7 @@ Mojolicious::Plugin::BasicAuthPlus - Basic HTTP Auth Helper Plus
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -213,8 +213,8 @@ or Active Directory.
 
 =head2 basic_auth
 
-Configure specific auth method (see OPTIONS).  Returns 1 on success, 0 on
-failure.
+Configure specific auth method (see CONFIGURATION).  Returns 1 on success,
+0 on failure.
 
 =head1 CONFIGURATION
 
